In console input record queue, replace semaphore with a manual reset
event, so that we get correct behavior in synchronization handling.

diff --git a/server/console.h b/server/console.h
index 95bae25..2fdb9d5 100644
--- a/server/console.h
+++ b/server/console.h
@@ -42,7 +42,7 @@
     int                          history_index; /* number of used entries in history array */
     int                          history_mode;  /* mode of history (non zero means remove doubled strings */
     int                          edition_mode;  /* index to edition mode flavors */
-    struct object               *wait_obj;      /* object to wait on for input queue */
+    struct event                *event;         /* event to wait on for input queue */
 };
 
 /* console functions */